Gnus development mailing list
 help / color / mirror / Atom feed
From: Reiner Steib <4uce.02.r.steib@gmx.net>
Subject: Re: [patch] More buttons for emacs stuff, MIDs, mail addresses
Date: Wed, 01 Jan 2003 21:38:32 +0100	[thread overview]
Message-ID: <v9vg181u7r.fsf@marauder.physik.uni-ulm.de> (raw)
In-Reply-To: <m3u1gs1yc0.fsf@quimbies.gnus.org> (Lars Magne Ingebrigtsen's message of "Wed, 01 Jan 2003 20:09:35 +0100")

[-- Attachment #1: Type: text/plain, Size: 257 bytes --]

On Wed, Jan 01 2003, Lars Magne Ingebrigtsen wrote:

> Reiner Steib <4uce.02.r.steib@gmx.net> writes:
>
>> I fixed the function and variable names:
>
> The attachment was empty; could you re-send?

Sure (the gnus-summary-resend-message-edit problem again):

[-- Warning: decoded text below may be mangled, UTF-8 assumed --]
[-- Attachment #2: message.rename-message-utils-stuff.patch --]
[-- Type: text/x-patch, Size: 7636 bytes --]

--- message.el.~6.266.~	Mon Dec 30 17:25:32 2002
+++ message.el	Mon Dec 30 17:30:54 2002
@@ -325,40 +325,40 @@
 ;; inspired by JoH-followup-to by Jochem Huhman <joh  at gmx.de>
 ;; new suggestions by R. Weikusat <rw at another.de>
 
-(defvar message-xpost-old-target nil
+(defvar message-cross-post-old-target nil
   "Old target for cross-posts or follow-ups.")
-(make-variable-buffer-local 'message-xpost-old-target)
+(make-variable-buffer-local 'message-cross-post-old-target)
 
 ;;;###autoload
-(defcustom message-xpost-default t
-  "When non-nil `message-xpost-fup2' will normally perform a crosspost.
-If nil, `message-xpost-fup2' will only do a followup.  Note that you
-can explicitly override this setting by calling `message-xpost-fup2'
-with a prefix."
+(defcustom message-cross-post-default t
+  "When non-nil `message-cross-post-followup-to' will normally perform a
+crosspost.  If nil, `message-cross-post-followup-to' will only do a followup.
+Note that you can explicitly override this setting by calling
+`message-cross-post-followup-to' with a prefix."
   :type 'boolean
   :group 'message-various)
 
 ;;;###autoload
-(defcustom message-xpost-note
+(defcustom message-cross-post-note
   "Crosspost & Followup-To: "
-  "Note to insert before signature to notify of xpost and follow-up."
+  "Note to insert before signature to notify of cross-post and follow-up."
   :type 'string
   :group 'message-various)
 
 ;;;###autoload
-(defcustom message-fup2-note
+(defcustom message-followup-to-note
   "Followup-To: "
   "Note to insert before signature to notify of follow-up only."
   :type 'string
   :group 'message-various)
 
 ;;;###autoload
-(defcustom message-xpost-note-function
-  'message-xpost-insert-note
+(defcustom message-cross-post-note-function
+  'message-cross-post-insert-note
   "Function to use to insert note about Crosspost or Followup-To.  
 The function will be called with four arguments.  The function should not only
 insert a note, but also ensure old notes are deleted.  See the documentation
-for `message-xpost-insert-note'. "
+for `message-cross-post-insert-note'. "
   :type 'function
   :group 'message-various)
 
@@ -1645,7 +1645,7 @@
       (message-sort-headers)))
 
 ;;;###autoload
-(defun message-xpost-fup2-header (target-group)
+(defun message-cross-post-followup-to-header (target-group)
   "Mangles FollowUp-To and Newsgroups header to point to TARGET-GROUP.
 With prefix-argument just set Follow-Up, don't cross-post."
   (interactive
@@ -1660,19 +1660,19 @@
   (message-goto-newsgroups)
   (beginning-of-line)
   ;; if we already did a crosspost before, kill old target
-  (if (and message-xpost-old-target
+  (if (and message-cross-post-old-target
 	   (re-search-forward
-	    (regexp-quote (concat "," message-xpost-old-target))
+	    (regexp-quote (concat "," message-cross-post-old-target))
 	    nil t))
       (replace-match ""))
   ;; unless (followup is to poster or user explicitly asked not
   ;; to cross-post, or target-group is already in Newsgroups)
   ;; add target-group to Newsgroups line.
   (cond ((and (or
-	       ;; def: xpost, req:no
-	       (and message-xpost-default (not current-prefix-arg))  
-	       ;; def: no-xpost, req:yes
-	       (and (not message-xpost-default) current-prefix-arg))
+	       ;; def: cross-post, req:no
+	       (and message-cross-post-default (not current-prefix-arg))  
+	       ;; def: no-cross-post, req:yes
+	       (and (not message-cross-post-default) current-prefix-arg))
 	      (not (string-match "poster" target-group))
 	      (not (string-match (regexp-quote target-group)
 				 (message-fetch-field "Newsgroups"))))
@@ -1686,13 +1686,14 @@
 				 "[ \t]*$")
 			 (message-fetch-field "Newsgroups")))
       (insert (concat "\nFollowup-To: " target-group)))
-  (setq message-xpost-old-target target-group))
+  (setq message-cross-post-old-target target-group))
 
 ;;;###autoload
-(defun message-xpost-insert-note (target-group xpost in-old old-groups)
+(defun message-cross-post-insert-note (target-group cross-post in-old
+						    old-groups)
   "Insert a in message body note about a set Followup or Crosspost.
 If there have been previous notes, delete them.  TARGET-GROUP specifies the
-group to Followup-To.  When XPOST is t, insert note about
+group to Followup-To.  When CROSS-POST is t, insert note about
 crossposting.  IN-OLD specifies whether TARGET-GROUP is a member of
 OLD-GROUPS.  OLD-GROUPS lists the old-groups the posting would have
 been made to before the user asked for a Crosspost."
@@ -1703,25 +1704,25 @@
 	       nil t))) ; just search in body
     (message-goto-signature)
     (while (re-search-backward
-	    (concat "^" (regexp-quote message-xpost-note) ".*")
+	    (concat "^" (regexp-quote message-cross-post-note) ".*")
 	    head t)
       (message-delete-line))
     (message-goto-signature)
     (while (re-search-backward
-	    (concat "^" (regexp-quote message-fup2-note) ".*")
+	    (concat "^" (regexp-quote message-followup-to-note) ".*")
 	    head t)
       (message-delete-line))
     ;; insert new note
     (if (message-goto-signature)
 	(re-search-backward message-signature-separator))
     (if (or in-old
-	    (not xpost)
+	    (not cross-post)
 	    (string-match "^[ \t]*poster[ \t]*$" target-group))
-	(insert (concat message-fup2-note target-group "\n"))
-      (insert (concat message-xpost-note target-group "\n")))))
+	(insert (concat message-followup-to-note target-group "\n"))
+      (insert (concat message-cross-post-note target-group "\n")))))
 
 ;;;###autoload
-(defun message-xpost-fup2 (target-group)
+(defun message-cross-post-followup-to (target-group)
   "Crossposts message and sets Followup-To to TARGET-GROUP.
 With prefix-argument just set Follow-Up, don't cross-post."
   (interactive
@@ -1750,13 +1751,13 @@
 				      "[ \t]*$")
 			      old-groups)))
 		    ;; yes, Newsgroups line must change
-		    (message-xpost-fup2-header target-group)
-		    ;; insert note whether we do xpost or fup2
-		    (funcall message-xpost-note-function
+		    (message-cross-post-followup-to-header target-group)
+		    ;; insert note whether we do cross-post or fup2
+		    (funcall message-cross-post-note-function
 			     target-group
-			     (if (or (and message-xpost-default
+			     (if (or (and message-cross-post-default
 					  (not current-prefix-arg))
-				     (and (not message-xpost-default)
+				     (and (not message-cross-post-default)
 					  current-prefix-arg)) t)
 			     in-old old-groups))))))))
 
@@ -1968,8 +1969,8 @@
   ;; modify headers (and insert notes in body)
   (define-key message-mode-map "\C-c\C-fs"    'message-change-subject)
   ;;
-  (define-key message-mode-map "\C-c\C-fx"    'message-xpost-fup2)
-  ;; prefix+message-xpost-fup2 = same w/o xpost
+  (define-key message-mode-map "\C-c\C-fx"    'message-cross-post-followup-to)
+  ;; prefix+message-cross-post-followup-to = same w/o cross-post
   (define-key message-mode-map "\C-c\C-ft"    'message-reduce-to-to-cc)
   (define-key message-mode-map "\C-c\C-fa"    'message-add-archive-header)
   ;; mark inserted text
@@ -2082,8 +2083,8 @@
     ["Keywords" message-goto-keywords t]
     ["Newsgroups" message-goto-newsgroups t]
     ["Followup-To" message-goto-followup-to t]
-    ;; ["Followup-To (with note in body)" message-xpost-fup2 t]
-    ["Crosspost / Followup-To..." message-xpost-fup2 t]
+    ;; ["Followup-To (with note in body)" message-cross-post-followup-to t]
+    ["Crosspost / Followup-To..." message-cross-post-followup-to t]
     ["Distribution" message-goto-distribution t]
     ["X-No-Archive:" message-add-archive-header t ]
     "----"

[-- Attachment #3: Type: text/plain, Size: 556 bytes --]


> That ChangeLog entry was just fine...

| 	message-cross-post-note-function, ): New variables names.
                                        ^^ this ", " should be removed.

>> E.g. `message-gen-unsubscribed-mft'?
>
> No, that should also be renamed to something understandable, I think.

`message-generate-unsubscribed-mft' or
`message-generate-unsubscribed-mail-followup-to'?  There's also
`message-make-mft' and `message-make-fqdn'...

Bye, Reiner.
-- 
       ,,,
      (o o)
---ooO-(_)-Ooo--- PGP key available via WWW   http://rsteib.home.pages.de/

  reply	other threads:[~2003-01-01 20:38 UTC|newest]

Thread overview: 44+ messages / expand[flat|nested]  mbox.gz  Atom feed  top
     [not found] <lcoumukovevvjjmjdn1svsl8ns6316aoca@4ax.com>
     [not found] ` <3D6FED17.6040201@yahoo.com.cn>
     [not found]   ` <m3ptvr2j4k.fsf@hartford-hwp.com>
     [not found]     ` <ilu8z2c4hl5.fsf@latte.josefsson.org>
     [not found]       ` <alfu5t$m59$1@quimby.gnus.org>
2002-09-09 12:43         ` Buttonize man page links Reiner Steib
2002-09-09 13:12           ` Simon Josefsson
2002-09-09 14:12             ` Reiner Steib
2002-09-09 14:16             ` Per Abrahamsen
2002-09-09 17:15               ` Andreas Fuchs
2002-09-10  7:26             ` Mats Lidell
2002-09-18 20:41             ` [patch] More buttons for emacs stuff, MIDs, mail addresses (was: Buttonize man page links) Reiner Steib
2002-09-19 11:42               ` [patch] More buttons for emacs stuff, MIDs, mail addresses Reiner Steib
2002-09-20 15:58               ` Kai Großjohann
2002-09-23 18:12                 ` Reiner Steib
2002-09-23 19:55                   ` Kai Großjohann
2002-09-24  0:32                     ` Katsumi Yamaoka
2002-09-24  8:07                       ` Kai Großjohann
2002-09-24 12:40                         ` Katsumi Yamaoka
2002-09-24 20:28                         ` XEmacs compiler warnings (was: [patch] More buttons for emacs stuff, MIDs, mail addresses) Reiner Steib
2002-09-25 13:16                           ` XEmacs compiler warnings Kai Großjohann
2002-09-25 17:44                             ` Reiner Steib
2002-09-24 20:29                       ` [patch] More buttons for emacs stuff, MIDs, mail addresses Reiner Steib
2002-09-24 20:39                         ` Paul Jarc
2002-09-24 22:15                           ` Reiner Steib
2002-09-25 13:52                         ` Kai Großjohann
2002-09-25 14:51                           ` Reiner Steib
2002-09-25 15:02                             ` Kai Großjohann
2002-09-24 19:28                   ` Raymond Scholz
2002-09-24 19:49                     ` Frank Schmitt
2002-09-24 20:56                     ` Reiner Steib
2002-10-16 17:20                       ` Raymond Scholz
2002-10-16 20:10                         ` Raymond Scholz
2002-10-17 15:03                         ` Reiner Steib
2002-12-29 17:55                       ` Lars Magne Ingebrigtsen
2002-12-30 17:58                         ` Reiner Steib
2003-01-01 19:09                           ` Lars Magne Ingebrigtsen
2003-01-01 20:38                             ` Reiner Steib [this message]
2003-01-01 20:59                               ` Lars Magne Ingebrigtsen
2003-01-07 18:21                                 ` Docu and menu patches for message.el/message.texi (was: [patch] More buttons for emacs stuff, MIDs, mail addresses) Reiner Steib
2003-01-08  4:08                                   ` Docu and menu patches for message.el/message.texi Lars Magne Ingebrigtsen
2003-01-08 12:03                                     ` Reiner Steib
2003-01-08 12:28                                       ` Lars Magne Ingebrigtsen
2003-01-08 15:12                                         ` Reiner Steib
2003-01-08 16:05                                           ` Lars Magne Ingebrigtsen
2003-01-02 16:47                         ` [patch] More buttons for emacs stuff, MIDs, mail addresses Reiner Steib
2003-01-02 18:00                           ` Henrik Enberg
2003-01-02 18:16                             ` Norbert Koch
2003-01-02 18:29                           ` Lars Magne Ingebrigtsen

Reply instructions:

You may reply publicly to this message via plain-text email
using any one of the following methods:

* Save the following mbox file, import it into your mail client,
  and reply-to-all from there: mbox

  Avoid top-posting and favor interleaved quoting:
  https://en.wikipedia.org/wiki/Posting_style#Interleaved_style

* Reply using the --to, --cc, and --in-reply-to
  switches of git-send-email(1):

  git send-email \
    --in-reply-to=v9vg181u7r.fsf@marauder.physik.uni-ulm.de \
    --to=4uce.02.r.steib@gmx.net \
    --cc=reiner.steib@gmx.de \
    /path/to/YOUR_REPLY

  https://kernel.org/pub/software/scm/git/docs/git-send-email.html

* If your mail client supports setting the In-Reply-To header
  via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line before the message body.
This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox;
as well as URLs for NNTP newsgroup(s).